<?php

// autoload.php @generated by Composer

define('GTOPDIR', realpath(implode(DIRECTORY_SEPARATOR, [__DIR__, '..', '..'])));
define('UMAPI_PATH', GTOPDIR . DIRECTORY_SEPARATOR . 'grommunio-mapi-header-php');

require_once __DIR__ . '/composer/autoload_real.php';

return ComposerAutoloaderInit153a56a781a72686b71399955d98204f::getLoader();
